Crate altv_internal_resource_before_unload_macro

Crate altv_internal_resource_before_unload_macro 

Attribute Macros

resource_before_unload
Defines before_unload callback of your alt:V Rust resource. It will be called when resource is unloaded when reload feature is enabled, for example using stop <resource name> command in the server console.